<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Over </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contact opnemen</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>License: </source>
        <translation>Licentie: </translation>
    </message>
    <message>
        <source>Screenshot and Annotation Tool</source>
        <translation>Schermfoto- en aantekeningsprogramma</translation>
    </message>
</context>
<context>
    <name>ActionSettingTab</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Sneltoets</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Take Capture</source>
        <translation>Schermfoto maken</translation>
    </message>
    <message>
        <source>Include Cursor</source>
        <translation>Cursor tonen op schermfoto</translation>
    </message>
    <message>
        <source>Delay</source>
        <translation>Wachttijd</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Capture Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Show image in Pin Window</source>
        <translation>Schermfoto tonen op overzichtsvenster</translation>
    </message>
    <message>
        <source>Copy image to Clipboard</source>
        <translation>Schermfoto kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Upload image</source>
        <translation>Schermfoto uploaden</translation>
    </message>
    <message>
        <source>Open image parent directory</source>
        <translation>Bijbehorende map openen</translation>
    </message>
    <message>
        <source>Save image</source>
        <translation>Schermfoto opslaan</translation>
    </message>
    <message>
        <source>Hide Main Window</source>
        <translation>Hoofdvenster verbergen</translation>
    </message>
</context>
<context>
    <name>ActionsSettings</name>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Actions Settings</source>
        <translation>Actie-instellingen</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Actie</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Watermerkafbeelding vereist</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Voeg een watermerkafbeelding toe via Opties --&gt; Instellingen --&gt; Aantekeningen --&gt; Bijwerken</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Gladvegen</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Schakel dit in om pen- en markeerstrepen
na afloop glad te vegen.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Gladveegfactor</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Het verhogen van de factor vermindert de
precisie, maar maakt pen- en markeerstrepen
gladder.</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Aantekeningsinstellingen</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Aantekeningsgereedschap onthouden en laden na opstarten</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation>Overschakelen naar selectiegereedschap na tekenen</translation>
    </message>
    <message>
        <source>Number Tool Seed change updates all Number Items</source>
        <translation>Getalwijziging werkt alle items met getallen bij</translation>
    </message>
    <message>
        <source>Disabling this option causes changes of the number tool
seed to affect only new items but not existing items.
Disabling this option allows having duplicate numbers.</source>
        <translation>Schakel deze optie uit om alleen nieuwe items
en niet ook bestaande items te wijzigen.
Hierdoor zijn duplicaten mogelijk.</translation>
    </message>
    <message>
        <source>Canvas Color</source>
        <translation>Canvaskleur</translation>
    </message>
    <message>
        <source>Default Canvas background color for annotation area.
Changing color affects only new annotation areas.</source>
        <translation>De standaard achtergrondkleur van het aantekeningsgebied.
Dit is alleen van toepassing op nieuwe aantekeningsgebieden.</translation>
    </message>
    <message>
        <source>Select Item after drawing</source>
        <translation>Item selecteren na tekenen</translation>
    </message>
    <message>
        <source>With this option enabled the item gets selected after
being created, allowing changing settings.</source>
        <translation>Schakel in om een item te selecteren nadat het getekend is,
zodat de instellingen ervan kunnen worden aangepast.</translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Schermfoto vastleggen met standaardmodus bij opstarten</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Programmastijl</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Hiermee bepaal je het uiterlijk van het programma.
Herstart ksnip om de wijzigingen toe te passen.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Programma-instellingen</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Nieuwe schermfoto&apos;s automatisch kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Tabbladen gebruiken</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Herstart om de wijzigingen toe te passen.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Slechts één ksnip-proces toestaan</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Verberg de tabbladbalk als er één tabblad geopend is.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Schakel deze optie in om slechts één ksnip-proces toe te staan.
Alle hierna gestarte processen geven opdrachten door aan het eerste
en worden daarna afgesloten. Herstart alle ksnip-processen om deze
wijziging toe te passen.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation>Automatisch opstarten met vorige schermpositie van hoofdvenster</translation>
    </message>
    <message>
        <source>Auto hide Tabs</source>
        <translation>Tabbladen automatisch verbergen</translation>
    </message>
    <message>
        <source>Auto hide Docks</source>
        <translation>Panelen automatisch verbergen</translation>
    </message>
    <message>
        <source>On startup hide Toolbar and Annotation Settings.
Docks visibility can be toggled with the Tab Key.</source>
        <translation>Verberg bij het opstarten de werkbalk- en aantekeningsinstellingen.
Ze kunnen dan worden getoond/verborgen met de Tab-toets.</translation>
    </message>
    <message>
        <source>Auto resize to content</source>
        <translation>Automatisch aanpassen aan inhoud</translation>
    </message>
    <message>
        <source>Automatically resize Main Window to fit content image.</source>
        <translation>Pas de afmetingen van het hoofdvenster automatisch aan aan de schermfoto.</translation>
    </message>
    <message>
        <source>Enable Debugging</source>
        <translation>Foutopsporing inschakelen</translation>
    </message>
    <message>
        <source>Enables debug output written to the console.
Change requires ksnip restart to take effect.</source>
        <translation>Schrijft foutopsporingsinformatie weg naar een terminalvenster.
Herstart ksnip om de wijziging toe te passen.</translation>
    </message>
    <message>
        <source>Resize to content delay</source>
        <translation>Wachttijd alvorens te herschalen naar inhoud</translation>
    </message>
    <message>
        <source>Resizing to content is delay to allow the Window Manager to receive
the new content. In case that the Main Windows is not adjusted correctly
to the new content, increasing this delay might improve the behavior.</source>
        <translation>De wachttijd omtrent herschalen naar inhoud geldt voor de vensterbeheerder.
Als het hoofdvenster niet goed wordt aangepast aan de nieuwe inhoud,
dan kan deze wachttijd het gedrag verbeteren.</translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>Contributors:</source>
        <translation>Bijdragers:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Spaanse vertaling</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Nederlandse vertaling</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Russische vertaling</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Noorse (Bokmål) vertaling</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Franse vertaling</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Poolse vertaling</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap- en Flatpak-ondersteuning</translation>
    </message>
    <message>
        <source>The Authors:</source>
        <translation>De makers:</translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Waarschuwing - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>De schermfoto, %1%2%3, is bewerkt.
Wil je deze opslaan?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Teken een rechthoekig gebied met je cursor</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Leg het volledige scherm vast op alle beeldschermen</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Maak een schermfoto van het scherm waarop de cursor is</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Maak een schermfoto van het momenteel gefocuste venster</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Maak een schermfoto van het venster onder de cursor</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Maak een schermfoto van het laatst geselecteerde rechthoekige gebied</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Gebruik het schermfotoportaal om een schermfoto te maken</translation>
    </message>
</context>
<context>
    <name>ContactTab</name>
    <message>
        <source>Community</source>
        <translation>Gemeenschap</translation>
    </message>
    <message>
        <source>Bug Reports</source>
        <translation>Bugmeldingen</translation>
    </message>
    <message>
        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
        <translation>Als je vragen hebt, ideeën wilt delen of gewoon even een praatje wilt maken, &lt;br/&gt;neem dan deel aan onze %1- of %2-server.</translation>
    </message>
    <message>
        <source>Please use %1 to report bugs.</source>
        <translation>Meld bugs op %1.</translation>
    </message>
</context>
<context>
    <name>CopyAsDataUriOperation</name>
    <message>
        <source>Failed to copy to clipboard</source>
        <translation>Kopiëren naar klembord mislukt</translation>
    </message>
    <message>
        <source>Failed to copy to clipboard as base64 encoded image.</source>
        <translation>Het kopiëren naar het klembord als base64-versleutelde schermfoto is mislukt.</translation>
    </message>
    <message>
        <source>Copied to clipboard</source>
        <translation>Gekopieerd naar klembord</translation>
    </message>
    <message>
        <source>Copied to clipboard as base64 encoded image.</source>
        <translation>Gekopieerd naar het klembord als base64-versleutelde schermfoto.</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Schermfoto verwijderen</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>‘%1’ wordt verwijderd.
Weet je zeker dat je wilt doorgaan?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donations are always welcome</source>
        <translation>Donaties zijn altijd welkom</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Doneren</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip is een vrij softwareproject zonder winstoogmerk. Er zijn echter&lt;br/&gt;kosten die moeten worden gedekt,&lt;br/&gt;zoals domeinnaamkosten en hardware voor platform-onafhankelijke ondersteuning.</translation>
    </message>
    <message>
        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
        <translation>Als je wilt helpen of je waardering wilt tonen&lt;br/&gt;door de ontwikkelaars te trakteren op een biertje of kopje koffie, dan kan dat via %1deze pagina%2.</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor?</source>
        <translation>GitHub-sponsor worden?</translation>
    </message>
    <message>
        <source>Also possible, %1here%2.</source>
        <translation>Dat kan ook, namelijk via %1deze pagina%2.</translation>
    </message>
</context>
<context>
    <name>EmptyActionSettingTab</name>
    <message>
        <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
        <translation>Voeg nieuwe acties toe door de knop ‘Toevoegen’ aan te klikken.</translation>
    </message>
</context>
<context>
    <name>EnumTranslator</name>
    <message>
        <source>Rectangular Area</source>
        <translation>Rechthoekig gebied</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Vorig rechthoekig gebied</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Volledig scherm (alle beeldschermen)</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Huidig scherm</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Actief venster</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Venster onder cursor</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Schermfotoportaal</translation>
    </message>
</context>
<context>
    <name>FtpUploaderSettings</name>
    <message>
        <source>Force anonymous upload.</source>
        <translation>Dwing anoniem uploaden af.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP-upload</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Schermfoto geüpload</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>De tijdelijke schermfoto, nodig voor het uploaden, kan niet worden opgeslagen.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Het proces kan niet worden gestart. Controleer de locatie en toegangsrechten.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Het proces is gecrasht</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Het proces is verlopen.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Leesfout.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Schrijffout.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Netwerkfout. Controleer de opdrachtvensteruitvoer.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Uploaden mislukt</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Het script is weggeschreven naar StdErr.</translation>
    </message>
    <message>
        <source>FTP Upload finished successfully.</source>
        <translation>De ftp-upload is afgerond.</translation>
    </message>
    <message>
        <source>Unknown error.</source>
        <translation>Onbekende fout.</translation>
    </message>
    <message>
        <source>Connection Error.</source>
        <translation>Verbindingsfout.</translation>
    </message>
    <message>
        <source>Permission Error.</source>
        <translation>Rechtenfout.</translation>
    </message>
    <message>
        <source>Upload script %1  finished successfully.</source>
        <translation>‘%1’ is uitgevoerd.</translation>
    </message>
    <message>
        <source>Uploaded to %1</source>
        <translation>Geüpload naar %1</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Algemene sneltoetsen inschakelen</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Rechthoekig gebied vastleggen</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Volledig scherm vastleggen</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Huidige scherm vastleggen</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Actief scherm vastleggen</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Venster onder cursor vastleggen</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Algemene sneltoetsen</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Vorig rechthoekig gebied vastleggen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Vastleggen met portaal</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11.
Disabling this option makes also the action shortcuts ksnip only.</source>
        <translation>Sneltoetsen worden momenteel alleen ondersteund op Windows en X11.
Schakel deze optie uit om de actiesneltoetsen alleen te gebruiken binnen KSnip.</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Cursor vastleggen bij maken van schermfoto</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Of de cursor zichtbaar moet zijn op
schermfoto&apos;s.</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Vastleggen</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Algemene Wayland-implementaties die XDG
DESKTOP PORTAL gebruiken, handelen beeldgroottes
allemaal anders af. Met deze optie wordt de huidige
beeldgrootte bepaald en toegepast op de schermfoto
in ksnip.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME en KDE Plasma ondersteunen zowel hun eigen
Wayland-implementatie als die van de algemene
XDG-DESKTOP-PORTAL. Schakel deze optie in om KDE Plasma
en GNOME XDG-DESKTOP-PORTAL te laten gebruiken voor het
maken van schermfoto&apos;s. Herstart ksnip om de wijziging toe te passen.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation>Hoofdvenster tonen na maken van schermfoto</translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation>Hoofdvenster verbergen tijdens maken van schermfoto</translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation>Verberg het hoofdvenster tijdens het maken van een schermfoto.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimize.</source>
        <translation>Toon het hoofdvenster na het maken van een schermfoto als
het hoofdvenster verborgen of geminimaliseerd is.</translation>
    </message>
    <message>
        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
        <translation>Algemene Wayland (xdg-desktop-portal)-schermfoto afdwingen</translation>
    </message>
    <message>
        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
        <translation>Algemene Wayland (xdg-desktop-portal)-schermfoto&apos;s schalen</translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur-geschiedenis</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Tijdstempel</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Link verwijderen</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>De schermfoto is geüpload naar imgur.com!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Nieuwe toegangssleutel ontvangen; bezig met opnieuw uploaden…</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Imgur-toegangssleutel verlopen; bezig met aanvragen van nieuwe…</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Anoniem uploaden</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Imgur-link altijd kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Client-id</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Client-geheim</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>Pincode</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Voer de imgur-pincode in. Deze wordt omgeruild voor een toegangssleutel.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>Pincode ophalen</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Toegangssleutel ophalen</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur-geschiedenis</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur-uploader</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Bezig met wachten op imgur.com…</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>De imgur.com-toegangssleutel is bijgewerkt.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Fout tijdens bijwerken van imgur.com-toegangssleutel.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Imgur-link na uploaden openen in standaardbrowser</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Directe link naar foto</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Basis-url:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>De basis-url voor communicatie met Imgur.
Herstart om de wijzigingen toe te passen.</translation>
    </message>
    <message>
        <source>Clear Token</source>
        <translation>Toegangssleutel wissen</translation>
    </message>
</context>
<context>
    <name>LoadImageFromFileOperation</name>
    <message>
        <source>Unable to open image</source>
        <translation>Kan schermfoto niet openen</translation>
    </message>
    <message>
        <source>Unable to open image from path %1</source>
        <translation>De schermfoto uit ‘%1’ kan niet worden geopend</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Nieuw</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>De wachttijd tussen het aanroepen en vastleggen
van een schermfoto, in seconden.</translation>
    </message>
    <message>
        <source>s</source>
        <extracomment>The small letter s stands for seconds.</extracomment>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Schermfoto lokaal opslaan</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Schermfoto kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Hulpmiddelen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Opnieuw uitvoeren</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Bijsnijden</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Schermfoto bijsnijden</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Niet-opgeslagen</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Afdrukvenster openen om de schermfoto af te drukken</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Afdrukvoorbeeld</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Afdrukvoorbeeld openen zodat de oriëntatie kan worden aangepast</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Grootte aanpassen</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>B&amp;ewerken</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opties</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Watermerk toevoegen</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Voorzie de schermfoto van een watermerk. Je kunt meerdere watermerken toevoegen.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Kan schermfoto niet tonen</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Opslaan als…</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Ingesloten plakken</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Vastmaken</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Schermfoto vastmaken aan voorgrond van naadloos venster</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Er werd een foto verwacht, maar niks opgegeven.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Locatie kopiëren</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Bekijken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation>Schermfoto&apos;s openen</translation>
    </message>
    <message>
        <source>Show Docks</source>
        <translation>Panelen tonen</translation>
    </message>
    <message>
        <source>Hide Docks</source>
        <translation>Panelen verbergen</translation>
    </message>
    <message>
        <source>Copy as data URI</source>
        <translation>Kopiëren als gegevensuri</translation>
    </message>
    <message>
        <source>Open &amp;Recent</source>
        <translation>&amp;Recent bestand openen</translation>
    </message>
    <message>
        <source>Modify Canvas</source>
        <translation>Canvas aanpassen</translation>
    </message>
    <message>
        <source>Upload triggerCapture to external source</source>
        <translation>Schermfoto uploaden naar externe dienst</translation>
    </message>
    <message>
        <source>Copy triggerCapture to system clipboard</source>
        <translation>Schermfoto kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Scale Image</source>
        <translation>Afmetingen aanpassen</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Draaien</translation>
    </message>
    <message>
        <source>Rotate Image</source>
        <translation>Foto draaien</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acties</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Locatie kopiëren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Vastleggen</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Anderen sluiten</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alles sluiten</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Venster %1 vastmaken</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation>De fotonaam is gewijzigd</translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation>Naamswijziging mislukt</translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation>Fotonaam wijzigen</translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation>Nieuwe bestandsnaam:</translation>
    </message>
    <message>
        <source>Successfully renamed image to %1</source>
        <translation>De afbeeldingsnaam is gewijzigd in ‘%1’</translation>
    </message>
    <message>
        <source>Failed to rename image to %1</source>
        <translation>De naam van ‘%1’ kan niet worden gewijzigd</translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Opslaan als</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>De schermfoto is opgeslagen</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Kan schermfoto niet opslaan</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Opgeslagen in %1</translation>
    </message>
    <message>
        <source>Failed to save image to %1</source>
        <translation>De afbeelding kan niet worden opgeslagen in %1</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Nieuwe schermfoto&apos;s automatisch opslaan op standaardlocatie</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation>Altijd vragen om aanpassingen op te slaan</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Recentste opslagmap onthouden</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Schakel in om de opslagmap uit de instellingen te vervangen door
de recentste opslagmap.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation>Opslaglocatie en bestandsnaam</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Ondersteunde bestandsformaten: JPG, PNG en BMP. Als je geen formaat opgeeft, dan wordt PNG gebruikt.
De bestandsnaam mag de volgende jokertekens bevatten:
- $Y, $M, $D voor datum, $h, $m, $s voor tijd, of $T voor tijd in de opmaak ‘uummss’.
- Gebruik # voor optelling. Voorbeeld: #### geeft 0001, met als opvolger 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Opslaginstellingen</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation>Opslaglocatie</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Opslagkwaliteit</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>Geef 0 op om bestanden met lage compressie te verkrijgen en 100 voor bestanden met
hoge compressie. Niet alle formaten ondersteunen det volledige bereik, maar jpeg wel.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Scriptuitvoer kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Script:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Locatie van het script dat moet worden gebruikt bij het uploaden. Tijdens het uploaden
wordt dit script aangeroepen op de locatie van de tijdelijke png.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Script-uploader</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Uploadscript kiezen</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Stoppen als uploadscript is weggeschreven naar StdErr</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Markeert de upload als ‘mislukt’ als het script wordt weggeschreven naar StdErr.
Schakel uit om scriptfouten te negeren.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Reguliere uitdrukking. Kopieer alleen tekst naar het klembord die hiermee overeenkomt.
Sla over om álles te kopiëren.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Vastleggen</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur-uploader</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Aantekeningen</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Uploader</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Script-uploader</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Stickers</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Vastleggebied</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation>Systeemvakpictogram</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Watermerk</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acties</translation>
    </message>
    <message>
        <source>FTP Uploader</source>
        <translation>FTP-upload</translation>
    </message>
</context>
<context>
    <name>SnippingAreaResizerInfoText</name>
    <message>
        <source>Resize selected rect using the handles or move it by dragging the selection.</source>
        <translation>Pas de grootte van het selectiegebied aan door de handgrepen te verschuiven of de selectie te verplaatsen.</translation>
    </message>
    <message>
        <source>Use arrow keys to move the selection.</source>
        <translation>Gebruik de pijltjestoetsen om de selectie te verplaatsen.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing CTRL to move top left handle.</source>
        <translation>Houd de Ctrl-toets ingedrukt en druk op de pijltjestoetsen om het bovenste linkerhandvat te verplaatsen.</translation>
    </message>
    <message>
        <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
        <translation>Houd de Alt-toets ingedrukt en druk op de pijltjestoetsen om het onderste rechterhandvat te verplaatsen.</translation>
    </message>
    <message>
        <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
        <translation>Bevestig de selectie door op Enter te drukken of breek af door op Esc te drukken.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Dit bericht kan in de instellingen worden uitgeschakeld.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSelectorInfoText</name>
    <message>
        <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
        <translation>Klik en sleep om een rechthoekig gebied te selecteren of druk op Esc om af te breken.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to resize selection after selecting.</source>
        <translation>Houd na het selecteren Ctrl ingedrukt om het gebied te verkleinen/vergroten.</translation>
    </message>
    <message>
        <source>Hold CTRL pressed to prevent resizing after selecting.</source>
        <translation>Houd na het selecteren Ctrl ingedrukt om vergroten/verkleinen te voorkomen.</translation>
    </message>
    <message>
        <source>Operation will be canceled after 60 sec when no selection made.</source>
        <translation>De handeling wordt na 60 sec. inactiviteit afgebroken.</translation>
    </message>
    <message>
        <source>This message can be disabled via settings.</source>
        <translation>Dit bericht kan in de instellingen worden uitgeschakeld.</translation>
    </message>
</context>
<context>
    <name>SnippingAreaSettings</name>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Schermfoto bevriezen tijdens vastleggen</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Schakel in om de achtergrond te bevriezen
tijdens het selecteren van een rechthoekig
gebied. Dit verandert tevens het gedrag
van vertraagde schermfoto&apos;s: de wachttijd
vindt plaats vóórdat het selectiegebied
wordt getoond. Deze optie is altijd
uitgeschakeld op Wayland en altijd ingeschakeld
op macOS.</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Vergrootglas tonen op vastleggebied</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Toont een vergrootglas om in te zoomen op de
achtergrondafbeelding. Deze optie werkt alleen als
‘Schermfoto bevriezen tijdens vastleggen’ is ingeschakeld.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Linialen tonen op vastleggebied</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Horizontale en verticale lijnen die lopen vanaf
de schermranden naar de cursor op het vastleggebied.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Positie- en afmetingsinformatie tonen op vastleggebied</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Als de linkermuisknop niet wordt ingedrukt, wordt de
positie getoond. Als de knop wél wordt ingedrukt,
wordt de grootte van het selectiegebied links en
bovenaan getoond.</translation>
    </message>
    <message>
        <source>Allow resizing rect area selection by default</source>
        <translation>Vergroten/Verkleinen van selectiegebied toestaan</translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation>Schakel in om de afmetingen van het
gebied van een rechthoekige selectie aan te
passen. Druk na het aanpassen op Enter om
op te slaan.</translation>
    </message>
    <message>
        <source>Show Snipping Area info text</source>
        <translation>Informatietekst tonen op vastleggebied</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Cursorkleur binnen vastleggebied</translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation>Stel de kleur in van de cursor op het vastleggebied.</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Cursordikte binnen vastleggebied</translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation>Stel de dikte in van de cursor op het vastleggebied.</translation>
    </message>
    <message>
        <source>Snipping Area</source>
        <translation>Vastleggebied</translation>
    </message>
    <message>
        <source>Snipping Area adorner color</source>
        <translation>Versierkleur van vastleggebied</translation>
    </message>
    <message>
        <source>Sets the color of all adorner elements
on the snipping area.</source>
        <translation>Stelt de kleur in van versierde elementen
in het vastleggebied.</translation>
    </message>
    <message>
        <source>Snipping Area Transparency</source>
        <translation>Doorzichtigheid van vastleggebied</translation>
    </message>
    <message>
        <source>Alpha for not selected region on snipping area.
Smaller number is more transparent.</source>
        <translation>De alfawaarde van niet-geselecteerde gebieden in het selectiegebied.
Lager = doorzichtiger.</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Omhoog</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Omlaag</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Standaardstickers gebruiken</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Stickerinstellingen</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Vector-afbeeldingsbestanden (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation>Stickers toevoegen</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Bewerker tonen</translation>
    </message>
</context>
<context>
    <name>TrayIconSettings</name>
    <message>
        <source>Use Tray Icon</source>
        <translation>Systeemvakpictogram gebruiken</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Schakel dit in om, als je vensterbeheerder dit ondersteunt, een systeemvakpictogram te gebruiken.
Herstart om de wijziging toe te passen.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Minimaliseren naar systeemvak</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Geminimaliseerd in systeemvak opstarten</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Sluiten naar systeemvak</translation>
    </message>
    <message>
        <source>Show Editor</source>
        <translation>Bewerker tonen</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Vastleggen</translation>
    </message>
    <message>
        <source>Default Tray Icon action</source>
        <translation>Standaard systeemvakpictogramactie</translation>
    </message>
    <message>
        <source>Default Action that is triggered by left clicking the tray icon.</source>
        <translation>De standaardactie na het klikken op het systeemvakpictogram.</translation>
    </message>
    <message>
        <source>Tray Icon Settings</source>
        <translation>Systeemvakinstellingen</translation>
    </message>
    <message>
        <source>Use platform specific notification service</source>
        <translation>Systeemmeldingen tonen</translation>
    </message>
    <message>
        <source>When enabled will use try to use platform specific notification
service when such exists. Change requires restart to take effect.</source>
        <translation>Schakel in om, indien mogelijk, systeemmeldingen te tonen.
Herstart KSnip om de wijziging toe te passen.</translation>
    </message>
    <message>
        <source>Display Tray Icon notifications</source>
        <translation>Systeemvakmeldingen tonen</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Foto kiezen</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Uploadscript vereist</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Voeg een uploadscript toe via Opties --&gt; Instellingen --&gt; Uploadscript</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Schermfoto uploaden</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Je staat op het punt om een schermfoto te uploaden. Wil je doorgaan?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation>Vragen alvorens te uploaden</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Soort upload:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Script</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Uploader</translation>
    </message>
    <message>
        <source>FTP</source>
        <translation>FTP</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Bouwsel</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Gebruikmakend van:</translation>
    </message>
</context>
<context>
    <name>WatermarkSettings</name>
    <message>
        <source>Watermark Image</source>
        <translation>Watermerkafbeelding</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Bijwerken</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Watermerk draaien</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Gebruik deze optie om een watermerk toe te voegen dat 45° gedraaid is</translation>
    </message>
    <message>
        <source>Watermark Settings</source>
        <translation>Watermerkinstellingen</translation>
    </message>
</context>
</TS>
